Module Name:    src
Committed By:   ginsbach
Date:           Thu Feb 25 13:23:27 UTC 2016

Modified Files:
        src/usr.bin/indent: indent.c io.c pr_comment.c

Log Message:
Fix obvious contraction spelling mistakes by adding missing apostrophes.


To generate a diff of this commit:
cvs rdiff -u -r1.21 -r1.22 src/usr.bin/indent/indent.c
cvs rdiff -u -r1.16 -r1.17 src/usr.bin/indent/io.c
cvs rdiff -u -r1.9 -r1.10 src/usr.bin/indent/pr_comment.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.bin/indent/io.c
diff -u src/usr.bin/indent/io.c:1.16 src/usr.bin/indent/io.c:1.17
--- src/usr.bin/indent/io.c:1.16	Mon Feb 22 19:04:18 2016
+++ src/usr.bin/indent/io.c	Thu Feb 25 13:23:27 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: io.c,v 1.16 2016/02/22 19:04:18 ginsbach Exp $	*/
+/*	$NetBSD: io.c,v 1.17 2016/02/25 13:23:27 ginsbach Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -68,7 +68,7 @@
 #if 0
 static char sccsid[] = "@(#)io.c	8.1 (Berkeley) 6/6/93";
 #else
-__RCSID("$NetBSD: io.c,v 1.16 2016/02/22 19:04:18 ginsbach Exp $");
+__RCSID("$NetBSD: io.c,v 1.17 2016/02/25 13:23:27 ginsbach Exp $");
 #endif
 #endif				/* not lint */
 
@@ -130,7 +130,7 @@ dump_line(void)
 			n_real_blanklines = 0;
 			if (ps.ind_level == 0)
 				ps.ind_stmt = 0;	/* this is a class A
-							 * kludge. dont do
+							 * kludge. don't do
 							 * additional statement
 							 * indentation if we are
 							 * at bracket level 0 */
@@ -265,7 +265,7 @@ dump_line(void)
 								target = ((target - 1) & ~7) + 9, com_st++;
 							else
 								target = 1;
-					if (cur_col > target) {	/* if comment cant fit
+					if (cur_col > target) {	/* if comment can't fit
 								 * on this line, put it
 								 * on next line */
 						putc('\n', output);
@@ -393,7 +393,7 @@ fill_buffer(void)
 	char   *n;
 
 	if (bp_save != 0) {	/* there is a partly filled input buffer left */
-		buf_ptr = bp_save;	/* dont read anything, just switch
+		buf_ptr = bp_save;	/* don't read anything, just switch
 					 * buffers */
 		buf_end = be_save;
 		bp_save = be_save = 0;

Index: src/usr.bin/indent/pr_comment.c
diff -u src/usr.bin/indent/pr_comment.c:1.9 src/usr.bin/indent/pr_comment.c:1.10
--- src/usr.bin/indent/pr_comment.c:1.9	Thu Aug  7 11:14:09 2003
+++ src/usr.bin/indent/pr_comment.c	Thu Feb 25 13:23:27 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: pr_comment.c,v 1.9 2003/08/07 11:14:09 agc Exp $	*/
+/*	$NetBSD: pr_comment.c,v 1.10 2016/02/25 13:23:27 ginsbach Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -68,7 +68,7 @@
 #if 0
 static char sccsid[] = "@(#)pr_comment.c	8.1 (Berkeley) 6/6/93";
 #else
-__RCSID("$NetBSD: pr_comment.c,v 1.9 2003/08/07 11:14:09 agc Exp $");
+__RCSID("$NetBSD: pr_comment.c,v 1.10 2016/02/25 13:23:27 ginsbach Exp $");
 #endif
 #endif				/* not lint */
 
@@ -126,7 +126,7 @@ pr_comment(void)
 	int     l_just_saw_decl = ps.just_saw_decl;
 	/*
          * int         ps.last_nl = 0;	/ * true iff the last significant thing
-         * weve seen is a newline
+         * we've seen is a newline
          */
 	int     one_liner = 1;	/* true iff this comment is a one-liner */
 	adj_max_col = max_col;
@@ -159,8 +159,8 @@ pr_comment(void)
 		if ( /* ps.bl_line && */ (s_lab == e_lab) && (s_code == e_code)) {
 			/* klg: check only if this line is blank */
 			/*
-		         * If this (*and previous lines are*) blank, dont put comment way
-		         * out at left
+		         * If this (*and previous lines are*) blank, don't
+			 * put comment way out at left
 		         */
 			ps.com_col = (ps.ind_level - ps.unindent_displace) * ps.ind_size + 1;
 			adj_max_col = block_comment_max_col;
@@ -243,7 +243,7 @@ pr_comment(void)
 			}
 			one_liner = 0;
 			if (ps.box_com || ps.last_nl) {	/* if this is a boxed
-							 * comment, we dont
+							 * comment, we don't
 							 * ignore the newline */
 				if (s_com == e_com) {
 					*e_com++ = ' ';

Reply via email to
Index: src/usr.bin/indent/indent.c
diff -u src/usr.bin/indent/indent.c:1.21 src/usr.bin/indent/indent.c:1.22
--- src/usr.bin/indent/indent.c:1.21	Mon Feb 22 22:01:48 2016
+++ src/usr.bin/indent/indent.c	Thu Feb 25 13:23:27 2016
@@ -1,4 +1,4 @@
-/*	$NetBSD: indent.c,v 1.21 2016/02/22 22:01:48 ginsbach Exp $	*/
+/*	$NetBSD: indent.c,v 1.22 2016/02/25 13:23:27 ginsbach Exp $	*/
 
 /*
  * Copyright (c) 1980, 1993
@@ -75,7 +75,7 @@ __COPYRIGHT("@(#) Copyright (c) 1985 Sun
 #if 0
 static char sccsid[] = "@(#)indent.c	5.17 (Berkeley) 6/7/93";
 #else
-__RCSID("$NetBSD: indent.c,v 1.21 2016/02/22 22:01:48 ginsbach Exp $");
+__RCSID("$NetBSD: indent.c,v 1.22 2016/02/25 13:23:27 ginsbach Exp $");
 #endif
 #endif				/* not lint */
 
@@ -260,7 +260,7 @@ main(int argc, char **argv)
 		}
 	}
 	if (ps.com_ind <= 1)
-		ps.com_ind = 2;	/* dont put normal comments before column 2 */
+		ps.com_ind = 2;	/* don't put normal comments before column 2 */
 	if (troff) {
 		if (bodyf.font[0] == 0)
 			parsefont(&bodyf, "R");
@@ -355,7 +355,7 @@ main(int argc, char **argv)
 			case lbrace:	/* this is a brace that starts the
 					 * compound stmt */
 				if (sc_end == 0) {	/* ignore buffering if a
-							 * comment wasnt stored
+							 * comment wasn't stored
 							 * up */
 					ps.search_brace = false;
 					goto check_type;
@@ -420,7 +420,7 @@ main(int argc, char **argv)
 					force_nl = false;
 
 				if (sc_end == 0) {	/* ignore buffering if
-							 * comment wasnt saved
+							 * comment wasn't saved
 							 * up */
 					ps.search_brace = false;
 					goto check_type;
@@ -503,7 +503,7 @@ check_type:
 					diag(0, "Line broken");
 				flushed_nl = false;
 				dump_line();
-				ps.want_blank = false;	/* dont insert blank at
+				ps.want_blank = false;	/* don't insert blank at
 							 * line start */
 				force_nl = false;
 			}
@@ -623,7 +623,7 @@ check_type:
 				ps.last_u_d = true;	/* inform lexi that a
 							 * following operator is
 							 * unary */
-				ps.in_stmt = false;	/* dont use stmt
+				ps.in_stmt = false;	/* don't use stmt
 							 * continuation
 							 * indentation */
 
@@ -785,8 +785,8 @@ check_type:
 
 			ps.in_decl = (ps.dec_nest > 0);	/* if we were in a first
 							 * level structure
-							 * declaration, we arent
-							 * any more */
+							 * declaration, we
+							 * aren't any more */
 
 			if ((!sp_sw || hd_type != forstmt) && ps.p_l_follow > 0) {
 
@@ -801,8 +801,8 @@ check_type:
 						 * while, etc. with unbalanced
 						 * parens */
 					sp_sw = false;
-					parse(hd_type);	/* dont lose the if, or
-							 * whatever */
+					parse(hd_type);	/* don't lose the if,
+							 * or whatever */
 				}
 			}
 			*e_code++ = ';';
@@ -819,7 +819,7 @@ check_type:
 			break;
 
 		case lbrace:	/* got a '{' */
-			ps.in_stmt = false;	/* dont indent the {} */
+			ps.in_stmt = false;	/* don't indent the {} */
 			if (!ps.block_init)
 				force_nl = true;	/* force other stuff on
 							 * same line as '{' onto
@@ -856,7 +856,7 @@ check_type:
 				}
 			}
 			if (s_code == e_code)
-				ps.ind_stmt = false;	/* dont put extra
+				ps.ind_stmt = false;	/* don't put extra
 							 * indentation on line
 							 * with '{' */
 			if (ps.in_decl && ps.in_or_st) {	/* this is either a
@@ -865,9 +865,9 @@ check_type:
 				di_stack[ps.dec_nest++] = dec_ind;
 				/* ?		dec_ind = 0; */
 			} else {
-				ps.decl_on_line = false;	/* we cant be in the
+				ps.decl_on_line = false;	/* we can't be in the
 								 * middle of a
-								 * declaration, so dont
+								 * declaration, so don't
 								 * do special
 								 * indentation of
 								 * comments */
@@ -1088,7 +1088,7 @@ check_type:
 		case period:	/* treat a period kind of like a binary
 				 * operation */
 			*e_code++ = '.';	/* move the period into line */
-			ps.want_blank = false;	/* dont put a blank after a
+			ps.want_blank = false;	/* don't put a blank after a
 						 * period */
 			break;
 
@@ -1256,7 +1256,7 @@ check_type:
 						 * line here */
 				flushed_nl = false;
 				dump_line();
-				ps.want_blank = false;	/* dont insert blank at
+				ps.want_blank = false;	/* don't insert blank at
 							 * line start */
 				force_nl = false;
 			}
